{ config, pkgs, ... }: let
    packages = (import ../lib/packages.nix) { config = config.nixpkgs.config; };
    callPackageFile = path: (import path) packages;
in {
    imports = [
        (callPackageFile ../profiles/system/base.nix)

        (callPackageFile ../profiles/environment/graphical-environment.nix)
        (callPackageFile ../profiles/environment/xfce4.nix)

        (callPackageFile ../profiles/system/efi-boot.nix)
        (callPackageFile ../profiles/system/networked.nix)
        (callPackageFile ../profiles/system/printing.nix)
        (callPackageFile ../profiles/system/scanning.nix)
        (callPackageFile ../profiles/system/amd.nix)
        (callPackageFile ../profiles/system/pulseaudio.nix)
        (callPackageFile ../profiles/system/virtualization.nix)

        (callPackageFile ../profiles/software/postgresql.nix)
        (callPackageFile ../profiles/software/couchdb.nix)

        (callPackageFile ../profiles/software/light-games.nix)
        (callPackageFile ../profiles/software/games.nix)
        (callPackageFile ../profiles/software/bitcoin.nix)
        (callPackageFile ../profiles/software/browsers.nix)
        (callPackageFile ../profiles/software/development.nix)
        (callPackageFile ../profiles/software/diagnostics.nix)
        (callPackageFile ../profiles/software/downloaders.nix)
        (callPackageFile ../profiles/software/emulators.nix)
        (callPackageFile ../profiles/software/filesharing.nix)
        (callPackageFile ../profiles/software/guake.nix)
        (callPackageFile ../profiles/software/messaging.nix)
        (callPackageFile ../profiles/software/multimedia.nix)
        (callPackageFile ../profiles/software/node.nix)
        (callPackageFile ../profiles/software/productivity.nix)
        (callPackageFile ../profiles/software/synergy.nix)
        (callPackageFile ../profiles/software/workrave.nix)
        (callPackageFile ../profiles/software/graphical-base.nix)
    ];

    services.xserver = {
        xrandrHeads = [
            "DFP6"
            "CRT1"
        ];
    };

    networking = {
        hostName = "desktop-home";

        firewall = { # FIXME: abstract this out...
            allowedTCPPorts = [
                24800      # Synergy
                8999       # qBittorrent
                27273      # Workrave
            ];
        };
    };

    users.extraUsers.sven = {
        isNormalUser = true;
        uid = 1000;
        extraGroups = ["libvirtd"];
    };

    boot = {
        kernelModules = [ "tun" "virtio" "nbd" ];
    };

    fileSystems = [
        {
            mountPoint = "/mnt/storage1";
            device = "/dev/disk/by-uuid/f7b13747-f465-4600-9928-d7bf0720df1a";
        }
        {
            mountPoint = "/mnt/storage2";
            device = "/dev/disk/by-uuid/71cc55ca-7fc7-40c2-9dee-9e6216959d15";
        }
        {
            mountPoint = "/mnt/temp";
            device = "/dev/disk/by-uuid/6251105f-2b32-40de-859b-1654d6d1037e";
        }
        {
            mountPoint = "/mnt/opensuse";
            device = "/dev/disk/by-uuid/02a65154-3d26-4077-8942-c48337a3f9a2";
        }
    ];

    environment = {
        etc = {
            "synergy-server.conf" = {
                text = ''
                    section: screens
                        desktop:

                        laptop:

                    end

                    section: links
                        desktop:
                            left = laptop
                        laptop:
                            right = desktop
                    end

                    section: aliases
                        desktop:
                            192.168.178.60
                            desktop-home
                        laptop:
                            192.168.178.41
                            linux-o82e.site
                    end
                '';
            };
        };
    };
}
